#!/usr/bin/env python

from gnuradio import gr
from gnuradio import blocks, filter
import scipy, pylab, time
from scipy import fftpack

N = 1000000
start = 2
stop = 1024
step = 2

src0 = blocks.null_source(gr.sizeof_gr_complex)
src1 = blocks.null_source(gr.sizeof_gr_complex)
head0 = blocks.head(gr.sizeof_gr_complex, N)
head1 = blocks.head(gr.sizeof_gr_complex, N)
fir_filt = filter.fir_filter_ccc(1, [0,])
fft_filt = filter.fft_filter_ccc(1, [0,])
snk0 = blocks.null_sink(gr.sizeof_gr_complex)
snk1 = blocks.null_sink(gr.sizeof_gr_complex)

tb_fir = gr.top_block()
tb_fir.connect(src0, head0, fir_filt, snk0)

tb_fft = gr.top_block()
tb_fft.connect(src1, head1, fft_filt, snk1)

times_fir = []
times_fft = []
ntaps = xrange(start, stop, step)
for i in ntaps:
    print "ntaps: ", i
    taps = scipy.rand(i)
    fir_filt.set_taps(taps)
    fft_filt.set_taps(taps)

    head0.reset()
    start = time.time()
    tb_fir.run()
    end = time.time()
    times_fir.append(end - start)

    head1.reset()
    start = time.time()
    tb_fft.run()
    end = time.time()
    times_fft.append(end - start)


fig = pylab.figure(1, figsize=(12,10), facecolor='w')
sp1 = fig.add_subplot(1,1,1)
sp1.plot(ntaps, times_fir, 'b-o', label='FIR')
sp1.plot(ntaps, times_fft, 'r-s', label='FFT')
sp1.set_title("Time to compute {0} items".format(N), fontsize=20, fontweight='bold')
sp1.set_xlabel("Number of taps", fontsize=16, fontweight='bold')
sp1.set_ylabel("Time (s)", fontsize=16, fontweight='bold')
sp1.grid()
sp1.legend()

pylab.show()
